XChaCha20 class

Constructors

XChaCha20()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

decrypt({required String key, required String nonce, required String ciphertext}) Future<String>
encrypt({required String key, required String nonce, required String plaintext}) Future<String>